IICINTM_R

Type Alias IICINTM_R 

pub type IICINTM_R = BitReader<IICINTM_A>;
Field IICINTM reader - IIC Interrupt Mode Select

Aliased Type

pub struct IICINTM_R { /* private fields */ }

Implementations

Source

impl IICINTM_R

pub fn variant(&self) -> IICINTM_A

Get enumerated values variant

pub fn is_0(&self) -> bool

Checks if the value of the field is _0

pub fn is_1(&self) -> bool

Checks if the value of the field is _1