CKOEN_R

Type Alias CKOEN_R 

pub type CKOEN_R = BitReader<CKOEN_A>;
Field CKOEN reader - Clock Out Enable

Aliased Type

pub struct CKOEN_R { /* private fields */ }

Implementations

Source

impl CKOEN_R

pub fn variant(&self) -> CKOEN_A

Get enumerated values variant

pub fn is_0(&self) -> bool

Checks if the value of the field is _0

pub fn is_1(&self) -> bool

Checks if the value of the field is _1